@@ -1,5 +1,5 @@
 package PAR::Heavy;
-$PAR::Heavy::VERSION = '0.11';
+$PAR::Heavy::VERSION = '0.12';
 
 =head1 NAME
 
@@ -19,7 +19,6 @@ No user-serviceable parts inside.
 # Dynamic inclusion of XS modules
 
 my ($bootstrap, $dl_findfile);  # Caches for code references
-my ($dlext);                    # Cache for $Config{dlext}
 my ($cache_key);                # The current file to find
 my $is_insensitive_fs = (
     -s $0
@@ -67,15 +66,8 @@ sub _bootstrap {
         $modfname = substr($modfname, 0, 8);
     }
 
-    # XXX: Multi-platform .dll support in PARs needs better than $Config.
-    # FIXME: Config is always loaded by PAR.pm!
-    $dlext ||= do {
-        require Config;
-        (defined %Config::Config) ? $Config::Config{dlext} : '';
-    };
-
     my $modpname = join((($^O eq 'MacOS') ? ':' : '/'), @modparts);
-    my $file = $cache_key = "auto/$modpname/$modfname.$dlext";
+    my $file = $cache_key = "auto/$modpname/$modfname.$DynaLoader::dl_dlext";
 
     if ($FullCache{$file}) {
         # TODO: understand
@@ -84,7 +76,7 @@ sub _bootstrap {
     }
 
     my $member;
-    # First, try to find things in the peferentially loaded PARs:
+    # First, try to find things in the preferentially loaded PARs:
     $member = PAR::_find_par_internals([@PAR::PAR_INC], undef, $file, 1)
       if defined &PAR::_find_par_internals;
 
@@ -118,7 +110,7 @@ sub _bootstrap {
 
             my $name = $member->fileName;
             next if $name eq $first;
-            next unless $name =~ m{^/?\Q$path_pattern\E\/[^/]*\.\Q$dlext\E[^/]*$};
+            next unless $name =~ m{^/?\Q$path_pattern\E\/[^/]*\.\Q$DynaLoader::dl_dlext\E[^/]*$};
             $name =~ s{.*/}{};
             _dl_extract($member, $file, $name);
         }
@@ -145,7 +137,7 @@ sub _dl_extract {
     if ($ENV{PAR_CLEAN} and !$name) {
         ($fh, $filename) = File::Temp::tempfile(
             DIR         => ($ENV{PAR_TEMP} || File::Spec->tmpdir),
-            SUFFIX      => ".$dlext",
+            SUFFIX      => ".$DynaLoader::dl_dlext",
             UNLINK      => ($^O ne 'MSWin32' and $^O !~ /hpux/),
         );
         ($filename) = $filename =~ /^([\x20-\xff]+)$/;
@@ -153,7 +145,7 @@ sub _dl_extract {
     else {
         $filename = File::Spec->catfile(
             ($ENV{PAR_TEMP} || File::Spec->tmpdir),
-            ($name || ($member->crc32String . ".$dlext"))
+            ($name || ($member->crc32String . ".$DynaLoader::dl_dlext"))
         );
         ($filename) = $filename =~ /^([\x20-\xff]+)$/;
 
@@ -166,7 +158,7 @@ sub _dl_extract {
         binmode($fh);
         $member->extractToFileHandle($fh);
         close $fh;
-        chmod 0755, $filename;
+        chmod 0750, $filename;
     }
 
     return $filename;
@@ -190,10 +182,10 @@ Please submit bug reports to E<lt>bug-par@rt.cpan.orgE<gt>.
 
 =head1 COPYRIGHT
 
-Copyright 2002-2009 by Audrey Tang
+Copyright 2002-2010 by Audrey Tang
 E<lt>cpan@audreyt.orgE<gt>.
 
-Copyright 2006-2009 by Steffen Mueller
+Copyright 2006-2010 by Steffen Mueller
 E<lt>smueller@cpan.orgE<gt>.
 
 This program is free software; you can redistribute it and/or modify it
